@@ -17,6 +17,7 @@
 from django.utils.translation import gettext_lazy as _
 
 import horizon
+from openstack_dashboard.dashboards.project import dashboard
 
 
 class Clusters(horizon.Panel):
@@ -25,4 +26,4 @@ class Clusters(horizon.Panel):
     permissions = ('openstack.services.database',)
 
 
-# dashboard.Project.register(Clusters)
+dashboard.Project.register(Clusters)
