@@ -18,19 +18,17 @@
 Views for managing database clusters.
 """
 from collections import OrderedDict
-import logging
 
-from django.core.urlresolvers import reverse
-from django.core.urlresolvers import reverse_lazy
-from django.utils.translation import ugettext_lazy as _
-
-import six
+from django.urls import reverse
+from django.urls import reverse_lazy
+from django.utils.translation import gettext_lazy as _
 
 from horizon import exceptions
 from horizon import forms as horizon_forms
 from horizon import tables as horizon_tables
 from horizon import tabs as horizon_tabs
 from horizon.utils import memoized
+from oslo_log import log as logging
 
 from trove_dashboard import api
 from trove_dashboard.content.database_clusters \
@@ -58,7 +56,7 @@ class IndexView(horizon_tables.DataTableView):
             flavors = []
             msg = _('Unable to retrieve database size information.')
             exceptions.handle(self.request, msg)
-        return OrderedDict((six.text_type(flavor.id), flavor)
+        return OrderedDict((str(flavor.id), flavor)
                            for flavor in flavors)
 
     def _extra_data(self, cluster):
@@ -86,7 +84,8 @@ class IndexView(horizon_tables.DataTableView):
             msg = _('Unable to retrieve database clusters.')
             exceptions.handle(self.request, msg)
 
-        map(self._extra_data, clusters)
+        for cluster in clusters:
+            self._extra_data(cluster)
 
         return clusters
 
