@@ -14,7 +14,7 @@
 
 from django.forms import ValidationError  # noqa
 from django.urls import reverse
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from horizon import exceptions
 from horizon import forms
@@ -188,7 +188,7 @@ class CreateUserForm(forms.SelfHandlingForm):
     def _get_databases(self, data):
         databases = []
         db_value = data['databases']
-        if db_value and db_value != u'':
+        if db_value and db_value != '':
             dbs = data['databases']
             databases = [{'name': d.strip()} for d in dbs.split(',')]
         return databases
@@ -281,3 +281,42 @@ class AttachConfigurationForm(forms.SelfHandlingForm):
                                          'group.'),
                               redirect=redirect)
         return True
+
+
+class UpdateInstanceForm(forms.SelfHandlingForm):
+    instance_id = forms.CharField(widget=forms.HiddenInput())
+    instance_name = forms.CharField(label=_("Name"))
+    allowed_cidrs = forms.MultiIPField(
+        label=_("Allowed CIDRs"),
+        required=False,
+        help_text=_("Classless Inter-Domain Routing "
+                    "(e.g. 192.168.0.0/24, or "
+                    "2001:db8::/128). Can enter multiple values separating"
+                    "by a comma"),
+        version=forms.IPv4 | forms.IPv6,
+        mask=True,
+        widget=forms.TextInput())
+
+    def __init__(self, request, *args, **kwargs):
+        super(UpdateInstanceForm, self).__init__(request, *args, **kwargs)
+        instance_id = kwargs.get('initial', {}).get('instance_id')
+        self.fields['instance_id'].initial = instance_id
+
+    def handle(self, request, data):
+        instance_id = data.get('instance_id')
+        allowed_cidrs = data.get('allowed_cidrs')
+        instance_name = data.get('instance_name')
+        update_kwargs = {'name': instance_name}
+        if allowed_cidrs:
+            update_kwargs['allowed_cidrs'] = allowed_cidrs.split(',')
+        try:
+            api.trove.instance_update(request, instance_id, **update_kwargs)
+
+            messages.success(request, _('Instance "%s" successfully updated.')
+                             % instance_name)
+        except Exception:
+            redirect = reverse("horizon:project:databases:index")
+            exceptions.handle(request, _('Unable to update instance "%s".'
+                                         % instance_id),
+                              redirect=redirect)
+        return True
