@@ -42,20 +42,21 @@ ACTIVE_STATES = ("ACTIVE", "HEALTHY",)
 
 class DeleteInstance(tables.DeleteAction):
     help_text = _("Deleted instances are not recoverable.")
+    policy_rules = (("database", "instance:delete"),)
 
     @staticmethod
     def action_present(count):
         return ngettext_lazy(
-            u"Delete Instance",
-            u"Delete Instances",
+            "Delete Instance",
+            "Delete Instances",
             count
         )
 
     @staticmethod
     def action_past(count):
         return ngettext_lazy(
-            u"Scheduled deletion of Instance",
-            u"Scheduled deletion of Instances",
+            "Scheduled deletion of Instance",
+            "Scheduled deletion of Instances",
             count
         )
 
@@ -66,20 +67,21 @@ class DeleteInstance(tables.DeleteAction):
 class RestartInstance(tables.BatchAction):
     help_text = _("Restarted instances will lose any data not"
                   " saved in persistent storage.")
+    policy_rules = (("database", "instance:restart"),)
 
     @staticmethod
     def action_present(count):
         return ngettext_lazy(
-            u"Restart Instance",
-            u"Restart Instances",
+            "Restart Instance",
+            "Restart Instances",
             count
         )
 
     @staticmethod
     def action_past(count):
         return ngettext_lazy(
-            u"Restarted Instance",
-            u"Restarted Instances",
+            "Restarted Instance",
+            "Restarted Instances",
             count
         )
 
@@ -99,16 +101,17 @@ class DetachReplica(tables.BatchAction):
     @staticmethod
     def action_present(count):
         return ngettext_lazy(
-            u"Detach Replica",
-            u"Detach Replicas",
+            "Detach Replica",
+            "Detach Replicas",
             count
         )
+    policy_rules = (("database", "instance:eject_replica_source"),)
 
     @staticmethod
     def action_past(count):
         return ngettext_lazy(
-            u"Replica Detached",
-            u"Replicas Detached",
+            "Replica Detached",
+            "Replicas Detached",
             count
         )
 
@@ -128,6 +131,7 @@ class PromoteToReplicaSource(tables.LinkAction):
     verbose_name = _("Promote to Replica Source")
     url = "horizon:project:databases:promote_to_replica_source"
     classes = ("ajax-modal", "btn-promote-to-replica-source")
+    policy_rules = (("database", "instance:promote_to_replica_source"),)
 
     def allowed(self, request, instance=None):
         return (instance.status in ACTIVE_STATES and
@@ -142,21 +146,22 @@ class EjectReplicaSource(tables.BatchAction):
     @staticmethod
     def action_present(count):
         return ngettext_lazy(
-            u"Eject Replica Source",
-            u"Eject Replica Sources",
+            "Eject Replica Source",
+            "Eject Replica Sources",
             count
         )
 
     @staticmethod
     def action_past(count):
         return ngettext_lazy(
-            u"Ejected Replica Source",
-            u"Ejected Replica Sources",
+            "Ejected Replica Source",
+            "Ejected Replica Sources",
             count
         )
 
     name = "eject_replica_source"
     classes = ('btn-danger', 'btn-eject-replica-source')
+    policy_rules = (("database", "instance:eject_replica_source"),)
 
     def _allowed(self, request, instance=None):
         return (instance.status != 'PROMOTE' and
@@ -170,21 +175,22 @@ class GrantAccess(tables.BatchAction):
     @staticmethod
     def action_present(count):
         return ngettext_lazy(
-            u"Grant Access",
-            u"Grant Access",
+            "Grant Access",
+            "Grant Access",
             count
         )
 
     @staticmethod
     def action_past(count):
         return ngettext_lazy(
-            u"Granted Access to",
-            u"Granted Access to",
+            "Granted Access to",
+            "Granted Access to",
             count
         )
 
     name = "grant_access"
     classes = ('btn-grant-access')
+    policy_rules = (("database", "instance:extension:user_access:update"),)
 
     def allowed(self, request, instance=None):
         if instance:
@@ -204,21 +210,22 @@ class RevokeAccess(tables.BatchAction):
     @staticmethod
     def action_present(count):
         return ngettext_lazy(
-            u"Revoke Access",
-            u"Revoke Access",
+            "Revoke Access",
+            "Revoke Access",
             count
         )
 
     @staticmethod
     def action_past(count):
         return ngettext_lazy(
-            u"Access Revoked to",
-            u"Access Revoked to",
+            "Access Revoked to",
+            "Access Revoked to",
             count
         )
 
     name = "revoke_access"
     classes = ('btn-revoke-access')
+    policy_rules = (("database", "instance:extension:user_access:delete"),)
 
     def allowed(self, request, instance=None):
         if instance:
@@ -246,6 +253,7 @@ def parse_host_param(request):
 
 class AccessTable(tables.DataTable):
     dbname = tables.Column("name", verbose_name=_("Name"))
+
     access = tables.Column(
         "access",
         verbose_name=_("Accessible"),
@@ -265,6 +273,7 @@ class ManageAccess(tables.LinkAction):
     verbose_name = _("Manage Access")
     url = "horizon:project:databases:access_detail"
     icon = "pencil"
+    policy_rules = (("database", "instance:extension:user_access:update"),)
 
     def allowed(self, request, instance=None):
         instance = self.table.kwargs['instance']
@@ -284,6 +293,7 @@ class CreateUser(tables.LinkAction):
     url = "horizon:project:databases:create_user"
     classes = ("ajax-modal",)
     icon = "plus"
+    policy_rules = (("database", "instance:extension:user:create"),)
 
     def allowed(self, request, instance=None):
         instance = self.table.kwargs['instance']
@@ -301,6 +311,7 @@ class EditUser(tables.LinkAction):
     url = "horizon:project:databases:edit_user"
     classes = ("ajax-modal",)
     icon = "pencil"
+    policy_rules = (("database", "instance:extension:user:update"),)
 
     def allowed(self, request, instance=None):
         instance = self.table.kwargs['instance']
@@ -322,19 +333,21 @@ def has_user_add_perm(request):
 
 
 class DeleteUser(tables.DeleteAction):
+    policy_rules = (("database", "instance:extension:user:delete"),)
+
     @staticmethod
     def action_present(count):
         return ngettext_lazy(
-            u"Delete User",
-            u"Delete Users",
+            "Delete User",
+            "Delete Users",
             count
         )
 
     @staticmethod
     def action_past(count):
         return ngettext_lazy(
-            u"Deleted User",
-            u"Deleted Users",
+            "Deleted User",
+            "Deleted Users",
             count
         )
 
@@ -350,6 +363,7 @@ class CreateDatabase(tables.LinkAction):
     url = "horizon:project:databases:create_database"
     classes = ("ajax-modal",)
     icon = "plus"
+    policy_rules = (("database", "instance:extension:database:create"),)
 
     def allowed(self, request, database=None):
         instance = self.table.kwargs['instance']
@@ -369,19 +383,21 @@ def has_database_add_perm(request):
 
 
 class DeleteDatabase(tables.DeleteAction):
+    policy_rules = (("database", "instance:extension:database:delete"),)
+
     @staticmethod
     def action_present(count):
         return ngettext_lazy(
-            u"Delete Database",
-            u"Delete Databases",
+            "Delete Database",
+            "Delete Databases",
             count
         )
 
     @staticmethod
     def action_past(count):
         return ngettext_lazy(
-            u"Deleted Database",
-            u"Deleted Databases",
+            "Deleted Database",
+            "Deleted Databases",
             count
         )
 
@@ -400,6 +416,7 @@ class LaunchLink(tables.LinkAction):
     url = "horizon:project:databases:launch"
     classes = ("ajax-modal", "btn-launch")
     icon = "cloud-upload"
+    policy_rules = (("database", "instance:create"),)
 
 
 class CreateBackup(tables.LinkAction):
@@ -408,6 +425,7 @@ class CreateBackup(tables.LinkAction):
     url = "horizon:project:database_backups:create"
     classes = ("ajax-modal",)
     icon = "camera"
+    policy_rules = (("database", "backup:create"),)
 
     def allowed(self, request, instance=None):
         return (instance.status in ACTIVE_STATES and
@@ -423,6 +441,7 @@ class ResizeVolume(tables.LinkAction):
     verbose_name = _("Resize Volume")
     url = "horizon:project:databases:resize_volume"
     classes = ("ajax-modal", "btn-resize")
+    policy_rules = (("database", "instance:resize_volume"),)
 
     def allowed(self, request, instance=None):
         return instance.status in ACTIVE_STATES
@@ -437,6 +456,7 @@ class ResizeInstance(tables.LinkAction):
     verbose_name = _("Resize Instance")
     url = "horizon:project:databases:resize_instance"
     classes = ("ajax-modal", "btn-resize")
+    policy_rules = (("database", "instance:resize_flavor"),)
 
     def allowed(self, request, instance=None):
         return ((instance.status in ACTIVE_STATES or
@@ -452,6 +472,7 @@ class AttachConfiguration(tables.LinkAction):
     verbose_name = _("Attach Configuration Group")
     url = "horizon:project:databases:attach_config"
     classes = ("btn-attach-config", "ajax-modal")
+    policy_rules = (("database", "instance:update"),)
 
     def allowed(self, request, instance=None):
         return (instance.status in ACTIVE_STATES and
@@ -462,21 +483,22 @@ class DetachConfiguration(tables.BatchAction):
     @staticmethod
     def action_present(count):
         return ngettext_lazy(
-            u"Detach Configuration Group",
-            u"Detach Configuration Groups",
+            "Detach Configuration Group",
+            "Detach Configuration Groups",
             count
         )
 
     @staticmethod
     def action_past(count):
         return ngettext_lazy(
-            u"Detached Configuration Group",
-            u"Detached Configuration Groups",
+            "Detached Configuration Group",
+            "Detached Configuration Groups",
             count
         )
 
     name = "detach_configuration"
     classes = ('btn-danger', 'btn-detach-config')
+    policy_rules = (("database", "instance:update"),)
 
     def allowed(self, request, instance=None):
         return (instance.status in ACTIVE_STATES and
@@ -489,6 +511,7 @@ class DetachConfiguration(tables.BatchAction):
 class EnableRootAction(tables.Action):
     name = "enable_root_action"
     verbose_name = _("Enable Root")
+    policy_rules = (("database", "instance:extension:root:create"),)
 
     def handle(self, table, request, obj_ids):
         try:
@@ -502,6 +525,7 @@ class EnableRootAction(tables.Action):
 class DisableRootAction(tables.Action):
     name = "disable_root_action"
     verbose_name = _("Disable Root")
+    policy_rules = (("database", "instance:extension:root:delete"),)
 
     def allowed(self, request, instance):
         enabled = api.trove.root_show(request, instance.id)
@@ -521,6 +545,9 @@ class ManageRoot(tables.LinkAction):
     name = "manage_root_action"
     verbose_name = _("Manage Root Access")
     url = "horizon:project:databases:manage_root"
+    policy_rules = (("database", "instance:extension:root:index"),
+                    ("database", "instance:extension:root:create"),
+                    ("database", "instance:extension:root:delete"))
 
     def allowed(self, request, instance):
         return instance.status in ACTIVE_STATES
@@ -532,6 +559,7 @@ class ManageRoot(tables.LinkAction):
 
 class ManageRootTable(tables.DataTable):
     name = tables.Column('name', verbose_name=_('Instance Name'))
+    policy_rules = (("database", "instance:extension:root:index"), )
     enabled = tables.Column('enabled',
                             verbose_name=_('Has Root Ever Been Enabled'),
                             filters=(d_filters.yesno, d_filters.capfirst),
@@ -659,20 +687,21 @@ class StopDatabase(tables.BatchAction):
     name = "stop_database"
     help_text = _("Stop database service inside an instance.")
     action_type = "danger"
+    policy_rules = (("database", "instance:extension:database:delete"), )
 
     @staticmethod
     def action_present(count):
         return ngettext_lazy(
-            u"Stop Database Service",
-            u"Stop Database Services",
+            "Stop Database Service",
+            "Stop Database Services",
             count
         )
 
     @staticmethod
     def action_past(count):
         return ngettext_lazy(
-            u"Database Service stopped",
-            u"Database Services stopped",
+            "Database Service stopped",
+            "Database Services stopped",
             count
         )
 
@@ -688,10 +717,10 @@ class UpdateInstance(tables.LinkAction):
     verbose_name = _("Update Instance")
     url = "horizon:project:databases:edit_instance"
     classes = ("btn-attach-config", "ajax-modal")
+    policy_rules = (("database", "instance:update"), )
 
     def allowed(self, request, instance=None):
-        return (instance.status in ACTIVE_STATES and
-                not hasattr(instance, 'configuration'))
+        return (instance.status in ACTIVE_STATES)
 
 
 class InstancesTable(tables.DataTable):
@@ -710,28 +739,28 @@ class InstancesTable(tables.DataTable):
     )
     STATUS_DISPLAY_CHOICES = (
         ("ACTIVE", pgettext_lazy("Current status of a Database Instance",
-                                 u"Active")),
+                                 "Active")),
         ("Healthy", pgettext_lazy("Current status of a Database Instance",
-                                  u"Healthy")),
+                                  "Healthy")),
         ("BLOCKED", pgettext_lazy("Current status of a Database Instance",
-                                  u"Blocked")),
+                                  "Blocked")),
         ("BUILD", pgettext_lazy("Current status of a Database Instance",
-                                u"Building")),
+                                "Building")),
         ("FAILED", pgettext_lazy("Current status of a Database Instance",
-                                 u"Failed")),
+                                 "Failed")),
         ("REBOOT", pgettext_lazy("Current status of a Database Instance",
-                                 u"Rebooting")),
+                                 "Rebooting")),
         ("RESIZE", pgettext_lazy("Current status of a Database Instance",
-                                 u"Resizing")),
+                                 "Resizing")),
         ("BACKUP", pgettext_lazy("Current status of a Database Instance",
-                                 u"Backup")),
+                                 "Backup")),
         ("SHUTDOWN", pgettext_lazy("Current status of a Database Instance",
-                                   u"Shutdown")),
+                                   "Shutdown")),
         ("ERROR", pgettext_lazy("Current status of a Database Instance",
-                                u"Error")),
+                                "Error")),
         ("RESTART_REQUIRED",
          pgettext_lazy("Current status of a Database Instance",
-                       u"Restart Required")),
+                       "Restart Required")),
     )
     name = tables.Column("name",
                          link="horizon:project:databases:detail",
