@@ -113,7 +113,7 @@ class SetInstanceDetailsAction(workflows.Action):
                                                        **kwargs)
         # Add this field to the end after the dynamic fields
         self.fields['locality'] = forms.ChoiceField(
-            label=_("Locality"),
+            label=_("Location Policy"),
             choices=[("", "None"),
                      ("affinity", "affinity"),
                      ("anti-affinity", "anti-affinity")],
@@ -626,9 +626,8 @@ class LaunchInstance(workflows.Workflow):
     def _get_nics(self, context):
         netids = context.get('network_id', None)
         if netids:
-            return [{"net-id": netid} for netid in netids]
-        else:
-            return None
+            return [{"network_id": netid} for netid in netids]
+        return None
 
     def _get_volume_type(self, context):
         volume_type = None
