@@ -10,11 +10,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 # The slug of the panel group to be added to HORIZON_CONFIG. Required.
 PANEL_GROUP = 'database'
 # The display name of the PANEL_GROUP. Required.
-PANEL_GROUP_NAME = _('Database')
+PANEL_GROUP_NAME = _('Databases')
 # The slug of the dashboard the PANEL_GROUP associated with. Required.
 PANEL_GROUP_DASHBOARD = 'project'
