@@ -22,10 +22,10 @@ PANEL_DASHBOARD = 'project'
 # The slug of the panel group the PANEL is associated with.
 PANEL_GROUP = 'database'
 
-DISABLED = True
+DISABLED = False
 
 # Python panel class of the PANEL to be added.
-ADD_PANEL = ('trove_dashboard.content.database_clusters.panel.Clusters')
+ADD_PANEL = 'trove_dashboard.content.database_clusters.panel.Clusters'
 
 ADD_EXCEPTIONS = {
     'not_found': exceptions.NOT_FOUND,
